==> ejc-outcontract-impl-3.0.0-20250928.114353-305-sources.jar: com/ejianc/foundation/calibration/vo/CalibrationSupplierVO.java <==
package com.ejianc.foundation.calibration.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 招标(定标)信息-供应商
 * 
 * @author generator
 * 
 */
public class CalibrationSupplierVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long calibrationId; // 招标(定标)信息ID
    private String supplierSysNo; // 项目编号
    private String supplierMainSysNo; // 项目编号
    private String supplierName; // 项目名称
    private Long supplierId; // 项目ID（平台）
    

    public Long getCalibrationId() {
        return calibrationId;
    }

    public void setCalibrationId(Long calibrationId) {
        this.calibrationId = calibrationId;
    }
    public String getSupplierSysNo() {
        return supplierSysNo;
    }

    public void setSupplierSysNo(String supplierSysNo) {
        this.supplierSysNo = supplierSysNo;
    }
    public String getSupplierMainSysNo() {
        return supplierMainSysNo;
    }

    public void setSupplierMainSysNo(String supplierMainSysNo) {
        this.supplierMainSysNo = supplierMainSysNo;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    
}

==> ejc-outcontract-impl-3.0.0-20251022.020553-368-sources.jar: com/ejianc/foundation/calibration/vo/CalibrationSupplierVO.java <==
package com.ejianc.foundation.calibration.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 招标(定标)信息-供应商
 * 
 * @author generator
 * 
 */
public class CalibrationSupplierVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long calibrationId; // 招标(定标)信息ID
    private String supplierStatus; // 供应商状态
    private String supplierSysNo; // 供应商编号
    private String supplierMainSysNo; // 供应商编号
    private String supplierName; // 供应商名称
    private Long supplierId; // 供应商ID（平台）
    

    public Long getCalibrationId() {
        return calibrationId;
    }

    public void setCalibrationId(Long calibrationId) {
        this.calibrationId = calibrationId;
    }
    public String getSupplierSysNo() {
        return supplierSysNo;
    }

    public void setSupplierSysNo(String supplierSysNo) {
        this.supplierSysNo = supplierSysNo;
    }
    public String getSupplierMainSysNo() {
        return supplierMainSysNo;
    }

    public void setSupplierMainSysNo(String supplierMainSysNo) {
        this.supplierMainSysNo = supplierMainSysNo;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierStatus() {
        return supplierStatus;
    }

    public void setSupplierStatus(String supplierStatus) {
        this.supplierStatus = supplierStatus;
    }
}
